========
Overview
========


Simple python driver for SDS011 PM sensor from Nova.

* Free software: MIT license

Installation
============



Documentation
=============


SDS011 datasheet http://cl.ly/ekot
This project is ispired by https://gist.github.com/kadamski/92653913a53baf9dd1a8


Development
===========

